==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/zh_HK.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "複製到剪貼板",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "First run wizard" : "首次使用精靈",
    "Add your profile information! For example your email is needed to receive notifications." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告及重設密碼。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照和全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照可以讓您在各種功能的界面當中快速被找到",
    "App recommendation: Nextcloud Calendar" : "推薦功能：Nextcloud Calendar",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "App recommendation: Nextcloud Contacts" : "推薦功能：Nextcloud Conracts",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
    "App recommendation: Nextcloud Mail" : "推薦功能：Nextcloud Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "App recommendation: Tasks" : "推薦功能：Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步任務並且線上編輯它們。",
    "App recommendation: Deck" : "推薦功能：Deck",
    "Kanban style organization for personal planning and team projects." : "以看板風格組織您的個人計劃和團隊專案。",
    "App recommendation: Notes" : "推薦功能：Notes",
    "Distraction-free notes and writing." : "無干擾的筆記與寫作。",
    "App recommendation: Social" : "推薦功能：Social",
    "Nextcloud becomes part of the federated social networks." : "Nextcloud 變成聯盟式社交網路的一部分。",
    "App recommendation: Group folders" : "推薦功能：Group folders",
    "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
    "About" : "關於",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的歡迎及介紹精靈",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此應用在用戶第一次登入 Nextcloud 時會開啟一個彈出式視窗。此視窗歡迎新的用戶來 Nextcloud 並且包含指引到標準桌面客戶端，Android app，及 iOS app的連結。此視窗也顯示使用 WebDAV存取 Nextcloud的連結。在任何時候，首次執行精靈可以在設定選單的\"關於\"連結再次開啟。\n首次執行精靈可以被自訂以符合特定設計目標，或是改變連結和訊息。遵照佈景主題文件建立合適的主題，並且改變此精靈外觀及感覺是很簡單。更多資訊可以在首次執行精靈文件看到，佈景主題文件也是。",
    "Start using {cloudName}" : "開始使用 {cloudName}",
    "Welcome to {cloudName}!" : "歡迎來到 {cloudName}！",
    "Extend your cloud" : "延伸您的雲",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "在應用程式商店中尋找超過一百個應用程式來客製化您的 Nextcloud",
    "Groupware apps like Calendar, Contacts, Mail" : "協作應用程式，像是日曆、聯絡人、電子郵件",
    "Communication with Nextcloud Talk" : "透過Nextcloud Talk傳送訊息或通話",
    "Collaboration apps for document editing" : "透過Collaboration進行文件編輯",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "安全及驗證特點如雙重認證，SSO及勒索軟件保護",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "許多其他功能，如音樂播放程式、密碼管理員、看板應用程式、下載管理程式或 Markdown 編輯器等",
    "Browse the App Store" : "瀏覽 app store",
    "Stay in sync" : "保持同步",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud 讓您無論身在何處都可以存取您的檔案",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "我們簡單易用的桌面和流動客戶端在各大平台上面免費提供！",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "Desktop client" : "桌面客戶端",
    "Android app" : "Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Connect your desktop apps to %s" : "連接您的桌面應用程式到 %s",
    "Connect your calendar" : "連接您的日曆",
    "Connect your contacts" : "連接您的聯絡人",
    "Access files via WebDAV" : "透過 WebDAV 存取檔案",
    "Download macOS/iOS configuration profile" : "下載 macOS/iOS 配置檔案\n \n \n ",
    "Get help" : "取得協助",
    "Get more information" : "取得更多資訊",
    "The Nextcloud documentation for home users:" : "家居用戶的 Nextcloud 文件：",
    "User manual" : "用戶手冊",
    "Admin manual" : "管理員手冊",
    "Developer manual" : "開發人員使用手冊",
    "You can also ask for help in our community support channels:" : "您也可以在我們的社群支援頻道尋求協助",
    "the Nextcloud forums" : "Nextcloud論壇",
    "the Nextcloud IRC chat channel on freenode.net" : "在freenode。net 上的 Nextcloud IRC 聊天頻道",
    "Start contributing" : "開始貢獻",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想要取得 Nextcloud 特定的改進嗎？您有找到問題嗎？你想要幫忙翻譯，推動或是寫 Nextcloud 文件嗎？",
    "Become part of the Community" : "成為社群的一份子",
    "Enterprise support" : "企業支援",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "如果您在有大量用戶與大量資料的關鍵任務環境中執行 Nextcloud，且需要 Nextcloud 技術背後的專家支援的話，則可以透過電子郵件與電話支援取得 Nextcloud 的企業訂閱。",
    "Get enterprise support" : "獲得企業級支援",
    "A safe home for all your data" : "您資料的安全屋",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 在您觸手可及的地方放置您的資料，在您的控制下。存放您的文件，日曆，聯絡人及相片在您公司，家中，任一個我們的提供者或是任何您知道的資料中心的伺服器上。",
    "Host your data and files where you decide" : "在您決定的位置存放您的資料與檔案",
    "Open Standards and Interoperability" : "開放標準及相互合作",
    "100%% Open Source & community-focused" : "100%% 專注於開源與社群",
    "Learn more about %s" : "了解更多關於%s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和流動裝置客戶端",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "使用統一 <a href=\"%s\">應用程式密碼</a> 去設定同步客戶端。如此，一旦遺失該設備，您就可以撤消存取權限。",
    "Connect other apps to %s" : "連結其他應用程式到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了流動裝置 apps 及桌面客戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟體到%s 。",
    "Server address" : "伺服器位址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此連結來連接您的應用程式及桌面客戶端到這伺服器：",
    "Copy link" : "複製連結",
    "Add your profile information! For example your email is needed to reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的 Email 才能在您需要時寄出密碼重設信件",
    "Start using Nextcloud" : "開始使用 Nextcloud",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "在應用程式商店中尋找超過一百個應用程式來客製化您的 Nextcloud",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "更多其他像是音樂播放器，密碼管理器，kanban app，下載管理器或是 markdown 編輯器",
    "Browse the app store" : "瀏覽 app store",
    "Previous" : "上一步",
    "Next" : "下一個"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/zh_HK.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "複製到剪貼板",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按⌘-C以複製。",
    "Press Ctrl-C to copy." : "請按Ctrl-C以複製。",
    "First run wizard" : "首次使用精靈",
    "Add your profile information! For example your email is needed to receive notifications." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "加入您的個人資訊吧！舉例來說，我們需要您的電郵地址才能寄出通告及重設密碼。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照和全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a full name for easier recognition across all features." : "加入您的個人資訊吧！例如加入全名可以讓您在各種功能的界面當中快速被找到",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "加入您的個人資訊吧！例如加入大頭貼照可以讓您在各種功能的界面當中快速被找到",
    "App recommendation: Nextcloud Calendar" : "推薦功能：Nextcloud Calendar",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "App recommendation: Nextcloud Contacts" : "推薦功能：Nextcloud Conracts",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
    "App recommendation: Nextcloud Mail" : "推薦功能：Nextcloud Mail",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "App recommendation: Tasks" : "推薦功能：Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步任務並且線上編輯它們。",
    "App recommendation: Deck" : "推薦功能：Deck",
    "Kanban style organization for personal planning and team projects." : "以看板風格組織您的個人計劃和團隊專案。",
    "App recommendation: Forms" : "推薦應用程式：Forms",
    "Simple surveys and questionnaires, self-hosted" : "📝 自託管的簡單調查和問卷",
    "App recommendation: Recognize" : "推薦應用程式：Recognize",
    "Smart media tagging for Nextcloud" : "Nextcloud 的智能媒體標記",
    "App recommendation: Group folders" : "推薦功能：Group folders",
    "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
    "About" : "關於",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的歡迎及介紹精靈",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此應用在用戶第一次登入 Nextcloud 時會開啟一個彈出式視窗。此視窗歡迎新的用戶來 Nextcloud 並且包含指引到標準桌面客戶端，Android app，及 iOS app的連結。此視窗也顯示使用 WebDAV存取 Nextcloud的連結。在任何時候，首次執行精靈可以在設定選單的\"關於\"連結再次開啟。\n首次執行精靈可以被自訂以符合特定設計目標，或是改變連結和訊息。遵照佈景主題文件建立合適的主題，並且改變此精靈外觀及感覺是很簡單。更多資訊可以在首次執行精靈文件看到，佈景主題文件也是。",
    "Start using {cloudName}" : "開始使用 {cloudName}",
    "Welcome to {cloudName}!" : "歡迎來到 {cloudName}！",
    "Extend your cloud" : "延伸您的雲",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "在應用程式商店中尋找超過一百個應用程式來客製化您的 Nextcloud",
    "Groupware apps like Calendar, Contacts, Mail" : "協作應用程式，像是日曆、聯絡人、電子郵件",
    "Communication with Nextcloud Talk" : "透過Nextcloud Talk傳送訊息或通話",
    "Collaboration apps for document editing" : "透過Collaboration進行文件編輯",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "安全及驗證特點如雙重認證，SSO及勒索軟件保護",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "許多其他功能，如音樂播放程式、密碼管理員、看板應用程式、下載管理程式或 Markdown 編輯器等",
    "Browse the App Store" : "瀏覽 app store",
    "Stay in sync" : "保持同步",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud 讓您無論身在何處都可以存取您的檔案",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "我們簡單易用的桌面和流動客戶端在各大平台上面免費提供！",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "Desktop client" : "桌面客戶端",
    "Android app on Google Play Store" : "Google Play Sore 中的 Android 應用程式",
    "Android app on F-Droid" : "F-Droid 中的 Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Connect your desktop apps to %s" : "連接您的桌面應用程式到 %s",
    "Connect your calendar" : "連接您的日曆",
    "Connect your contacts" : "連接您的聯絡人",
    "Access files via WebDAV" : "透過 WebDAV 存取檔案",
    "Download macOS/iOS configuration profile" : "下載 macOS/iOS 配置檔案\n \n \n ",
    "Get help" : "取得協助",
    "Start contributing" : "開始貢獻",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想要取得 Nextcloud 特定的改進嗎？您有找到問題嗎？你想要幫忙翻譯，推動或是寫 Nextcloud 文件嗎？",
    "Become part of the Community" : "成為社群的一份子",
    "Enterprise support" : "企業支援",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "如果您在安全性和合規性很重要的關鍵任務環境中運行 Nextcloud，則需要 Nextcloud Enterprise 的額外保護。",
    "Learn more about Nextcloud Enterprise" : "了解更多關於 Nextcloud Enterprise",
    "Get more information" : "取得更多資訊",
    "The Nextcloud documentation for home users:" : "家居用戶的 Nextcloud 文件：",
    "User manual" : "用戶手冊",
    "Admin manual" : "管理員手冊",
    "Developer manual" : "開發人員使用手冊",
    "You can also ask for help in our community support channels:" : "您也可以在我們的社群支援頻道尋求協助",
    "the Nextcloud forums" : "Nextcloud論壇",
    "A safe home for all your data" : "您資料的安全屋",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 在您觸手可及的地方放置您的資料，在您的控制下。存放您的文件，日曆，聯絡人及相片在您公司，家中，任一個我們的提供者或是任何您知道的資料中心的伺服器上。",
    "Host your data and files where you decide" : "在您決定的位置存放您的資料與檔案",
    "Open standards and interoperability" : "開放標準與互操作性",
    "100%% open source & community-focused" : "100%% 開放原始碼及以社群為中心",
    "Learn more about %s" : "了解更多關於%s",
    "This Nextcloud is on version %s" : "此 Nextcloud 版本為 %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s 讓您不管身在何處都可以存取您的檔案，我們免費提供各大主要平臺上簡單易用的桌面和流動裝置客戶端",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "使用統一 <a href=\"%s\">應用程式密碼</a> 去設定同步客戶端。如此，一旦遺失該設備，您就可以撤消存取權限。",
    "Connect other apps to %s" : "連結其他應用程式到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了流動裝置 apps 及桌面客戶端，您可以連結任何其他支援 WebDAV/CalDAV/CardDAV 協定的軟體到%s 。",
    "Server address" : "伺服器位址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此連結來連接您的應用程式及桌面客戶端到這伺服器：",
    "Copy link" : "複製連結",
    "App recommendation: Notes" : "推薦功能：Notes",
    "Distraction-free notes and writing." : "無干擾的筆記與寫作。",
    "Android app" : "Android 應用程式",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "如果您在有大量用戶與大量資料的關鍵任務環境中執行 Nextcloud，且需要 Nextcloud 技術背後的專家支援的話，則可以透過電子郵件與電話支援取得 Nextcloud 的企業訂閱。",
    "Get enterprise support" : "獲得企業級支援",
    "the Nextcloud IRC chat channel on freenode.net" : "在freenode.net 上的 Nextcloud IRC 聊天頻道",
    "Open Standards and Interoperability" : "開放標準及相互合作",
    "100%% Open Source & community-focused" : "100%% 專注於開源與社群"
},
"nplurals=1; plural=0;");
